@@ -9,7 +9,7 @@ from threading import Lock, Thread
 import six
 
 from virtualenv.dirs import default_data_dir
-from virtualenv.info import IS_WIN
+from virtualenv.info import fs_supports_symlink
 from virtualenv.seed.embed.base_embed import BaseEmbed
 from virtualenv.seed.embed.wheels.acquire import get_wheels
 
@@ -22,6 +22,7 @@ class FromAppData(BaseEmbed):
         super(FromAppData, self).__init__(options)
         self.clear = options.clear_app_data
         self.app_data_dir = default_data_dir() / "seed-v1"
+        self.symlinks = options.symlink_app_data
 
     @classmethod
     def add_parser_arguments(cls, parser, interpreter):
@@ -33,6 +34,16 @@ class FromAppData(BaseEmbed):
             help="clear the app data folder of seed images ({})".format((default_data_dir() / "seed-v1").path),
             default=False,
         )
+        can_symlink = fs_supports_symlink()
+        parser.add_argument(
+            "--symlink-app-data",
+            dest="symlink_app_data",
+            action="store_true" if can_symlink else "store_false",
+            help="{} symlink the python packages from the app-data folder (requires seed pip>=19.3)".format(
+                "" if can_symlink else "not supported - "
+            ),
+            default=False,
+        )
 
     def run(self, creator):
         if not self.enabled:
@@ -86,10 +97,8 @@ class FromAppData(BaseEmbed):
 
             yield name_to_whl
 
-    @staticmethod
-    def installer_class(pip_version):
-        # tbd: on Windows symlinks are unreliable, we have junctions for folders, however pip does not work well with it
-        if not IS_WIN:
+    def installer_class(self, pip_version):
+        if self.symlinks:
             # symlink support requires pip 19.3+
             pip_version_int = tuple(int(i) for i in pip_version.split(".")[0:2])
             if pip_version_int >= (19, 3):
@@ -97,4 +106,6 @@ class FromAppData(BaseEmbed):
         return CopyPipInstall
 
     def __unicode__(self):
-        return super(FromAppData, self).__unicode__() + " app_data_dir={}".format(self.app_data_dir.path)
+        return super(FromAppData, self).__unicode__() + " app_data_dir={} via={}".format(
+            self.app_data_dir.path, "symlink" if self.symlinks else "copy"
+        )
